import {Component, OnDestroy, OnInit} from "@angular/core";
import {StakeholderService} from "../openaireLibrary/monitor/services/stakeholder.service";
import {Stakeholder} from "../openaireLibrary/monitor/entities/stakeholder";
import {Subscription} from "rxjs";
import {Meta, Title} from "@angular/platform-browser";
import {SEOService} from "../openaireLibrary/sharedComponents/SEO/SEO.service";
import {properties} from "../../environments/environment";
import {ActivatedRoute, Router} from "@angular/router";

@Component({
  selector: 'methodology',
  template: `
		<div page-content>
			<div inner>
				<div class="uk-container uk-container-large">
          <h1>Terminology and <br> construction<span class="uk-text-primary">.</span></h1>
				</div>
				<div class="uk-section uk-container uk-container-large">
          <my-tabs>
            <my-tab [tabTitle]="'Entities'" [tabId]="'entities'" class="uk-active">
              <ng-container>
                <dl class="uk-description-list uk-description-list-divider">
                  <div class="uk-grid uk-padding-small" uk-grid>
                    <dt class="uk-width-1-5@m uk-width-1-1 uk-text-primary">Research Outcomes</dt>
                    <dd class="uk-width-expand">
                      <div>There are currently four different types of research outcomes in the OpenAIRE Research <br> Graph:</div>
                      <ul class="uk-list uk-list-disc">
                        <li>Publication</li>
                        <li>Dataset</li>
                        <li>Software</li>
                        <li>Other Research Product</li>
                      </ul>
                      <div class="uk-margin-small-top">
                        OpenAIRE deduplicates (merges) different records of research outcomes and keeps the <br> metadata of all instances.
                      </div>
                    </dd>
                  </div>
                  <hr>
                  <div class="uk-grid uk-padding-small" uk-grid>
                    <dt class="uk-width-1-5@m uk-width-1-1">Publication</dt>
                    <dd class="uk-width-expand">
                      Research outcomes intended for human reading (published articles, pre-prints, conference <br> papers, presentations, technical reports, etc.)
                    </dd>
                  </div>
                  <hr>
                  <div class="uk-grid uk-padding-small" uk-grid>
                    <dt class="uk-width-1-5@m uk-width-1-1">Dataset</dt>
                    <dd class="uk-width-expand">
                      <div>Research data</div>
                      <div>Granularity is not defined by OpenAIRE, it reflects the granularity supported by
                        the sources <br> from which the description of the dataset has been collected.</div>
                    </dd>
                  </div>
                  <hr>
                  <div class="uk-grid uk-padding-small" uk-grid>
                    <dt class="uk-width-1-5@m uk-width-1-1">Software</dt>
                    <dd class="uk-width-expand">
                      Source code or software package developed and/or used in a research context
                    </dd>
                  </div>
                  <hr>
                  <div class="uk-grid uk-padding-small" uk-grid>
                    <dt class="uk-width-1-5@m uk-width-1-1">Other Research Product</dt>
                    <dd class="uk-width-expand">
                      Anything that does not fall in the previous categories (e.g. workflow, methods, protocols)
                    </dd>
                  </div>
                </dl>
              </ng-container>
            </my-tab>
            <my-tab [tabTitle]="'Attributes of Entities'" [tabId]="'attributes'">
              <ng-container>
                <dl class="uk-description-list uk-description-list-divider">
                  <div class="uk-grid uk-padding-small" uk-grid>
                    <dt class="uk-width-1-5@m uk-width-1-1">Organization & Country</dt>
                    <dd class="uk-width-expand">
                      <p><span class="uk-text-bold">For research outcomes:</span> the affiliated organizations of its
                        authors (and their country)</p>
                      <p><span class="uk-text-bold">For projects:</span> the organizations participating in the project
                        (i.e. beneficiaries of the grant) and
                        their countries
                      </p>
                      <p>
                        <span class="uk-text-bold">Country code mapping: </span>
                        <a href="https://api.openaire.eu/vocabularies/dnet:countries" target="_blank">
                          https://api.openaire.eu/vocabularies/dnet:countries</a>
                      </p>
                    </dd>
                  </div>
                  <hr>
                  <div class="uk-grid uk-padding-small" uk-grid>
                    <dt class="uk-width-1-5@m uk-width-1-1">Type</dt>
                    <dd class="uk-width-expand">
                      <p>The sub-type of a research outcome (e.g., a publication can be a pre-print, conference proceeding,
                        article,
                        etc.)</p>
                      <p><span class="uk-text-bold">Resource type mapping: </span>
                        <a href="https://api.openaire.eu/vocabularies/dnet:result_typologies" target="_blank">https://api.openaire.eu/vocabularies/dnet:result_typologies</a>
                        (click on the code to see the specific types for each result type)
                      </p>
                    </dd>
                  </div>
                  <hr>
                  <div class="uk-grid uk-padding-small" uk-grid>
                    <dt class="uk-width-1-5@m uk-width-1-1">Access mode</dt>
                    <dd class="uk-width-expand">
                      <p>The best available (across all instances) access rights of a research outcome</p>
                      <p>Types: open, restricted, closed, embargo (= closed for a specific period of time, then open)</p>
                      <p><span class="uk-text-bold">Note:</span> definition of <span class="uk-text-bold">restricted</span>
                        may vary by data source.</p>
                    </dd>
                  </div>
                  <hr>
                  <div class="uk-grid uk-padding-small" uk-grid>
                    <dt class="uk-width-1-5@m uk-width-1-1">PID (persistent identifier)</dt>
                    <dd class="uk-width-expand">
                      <p>A long-lasting reference to a resource</p>
                      <p><span class="uk-text-bold">Types: </span> <a
                          href="http://api.openaire.eu/vocabularies/dnet:pid_types" target="_blank">http://api.openaire.eu/vocabularies/dnet:pid_types</a>
                      </p>
                    </dd>
                  </div>
                  <hr>
                  <div class="uk-grid uk-padding-small" uk-grid>
                    <dt class="uk-width-1-5@m uk-width-1-1">Context</dt>
                    <dd class="uk-width-expand">
                      Related research community, initiative or infrastructure.
                    </dd>
                  </div>
                  <hr>
                  <div class="uk-grid uk-padding-small" uk-grid>
                    <dt class="uk-width-1-5@m uk-width-1-1">Journal</dt>
                    <dd class="uk-width-expand">
                      The scientific journal an article is published in.
                    </dd>
                  </div>
                  <hr>
                  <div class="uk-grid uk-padding-small" uk-grid>
                    <dt class="uk-width-1-5@m uk-width-1-1">Publisher</dt>
                    <dd class="uk-width-expand">
                      The publisher of the venue (journal, book, etc.) of a research outcome.
                    </dd>
                  </div>
                  <hr>
                  <div class="uk-grid uk-padding-small" uk-grid>
                    <dt class="uk-width-1-5@m uk-width-1-1">Content Providers (Datasources)</dt>
                    <dd class="uk-width-expand">
                      <p>The different data sources ingested in the OpenAIRE Research Graph.</p>
                      <div class="uk-text-bold">Content Provider Types:</div>
                      <ul class="uk-list uk-list-disc">
                        <li>Repositories</li>
                        <li>Open Access Publishers & Journals</li>
                        <li>Aggregators</li>
                        <li>Entity Registries</li>
                        <li>Journal Aggregators</li>
                        <li>CRIS (Current Research Information System)</li>
                      </ul>
                    </dd>
                  </div>
                  <hr>
                  <div class="uk-grid uk-padding-small" uk-grid>
                    <dt class="uk-width-1-5@m uk-width-1-1">Repositories</dt>
                    <dd class="uk-width-expand">
                      Information systems where scientists upload the bibliographic metadata and payloads of their
                      research outcomes (e.g. PDFs of their scientific articles, CSVs of their data, archive with their
                      software), due to obligations from their organizations, their funders, or due to community practices
                      (e.g. ArXiv, Europe PMC, Zenodo).
                    </dd>
                  </div>
                  <hr>
                  <div class="uk-grid uk-padding-small" uk-grid>
                    <dt class="uk-width-1-5@m uk-width-1-1">Open Access Publishers & Journals</dt>
                    <dd class="uk-width-expand">
                      Information systems of open access publishers or relative journals, which offer bibliographic
                      metadata and PDFs of their published articles.
                    </dd>
                  </div>
                  <hr>
                  <div class="uk-grid uk-padding-small" uk-grid>
                    <dt class="uk-width-1-5@m uk-width-1-1">Aggregators</dt>
                    <dd class="uk-width-expand">
                      Information systems that collect descriptive metadata about research products from multiple sources
                      in order to enable cross-data source discovery of given research products (e,g, DataCite,
                      BASE, DOAJ).
                    </dd>
                  </div>
                  <hr>
                  <div class="uk-grid uk-padding-small" uk-grid>
                    <dt class="uk-width-1-5@m uk-width-1-1">Entity Registries</dt>
                    <dd class="uk-width-expand">
                      Information systems created with the intent of maintaining authoritative registries of given
                      entities in the scholarly communication, such as OpenDOAR for the institutional repositories, re3data
                      for the data repositories, CORDA and other funder databases for projects and funding information.
                    </dd>
                  </div>
                  <hr>
                  <div class="uk-grid uk-padding-small" uk-grid>
                    <dt class="uk-width-1-5@m uk-width-1-1">CRIS (Current Research Information System)</dt>
                    <dd class="uk-width-expand">
                      Information systems adopted by research and academic organizations to keep track of their research
                      administration records and relative results; examples of CRIS content are articles or datasets funded
                      by projects, their principal investigators, facilities acquired thanks to funding, etc.
                    </dd>
                  </div>
                </dl>
              </ng-container>
            </my-tab>
          </my-tabs>
          <div class="uk-margin-medium-top graph">
            <icon name="graph" customClass="uk-text-primary"></icon>
            <span class="uk-margin-small-left uk-text-baseline uk-text-muted">More information for <a
                href="https://graph.openaire.eu" class="uk-link">OpenAIRE Research Graph</a>.</span>
          </div>
				</div>
				<div id="how" class="uk-container uk-container-large uk-section uk-section-small uk-margin-large-top">
          <h2 class="uk-h1">
						Inclusion, transparency, <br> quality, state of the art <br> technology<span class="uk-text-primary">.</span>
          </h2>
          <div class="uk-margin-large-top uk-padding-small">
            <how></how>
          </div>
        </div>
			</div>
		</div>
  `,
  styleUrls: ['methodology.component.css']
})
export class MethodologyComponent implements OnInit, OnDestroy {
  public stakeholder: Stakeholder;
  public tab: 'entities' | 'attributes' = 'entities';
  private subscriptions: any[] = [];
  
  constructor(private stakeholderService: StakeholderService,
              private seoService: SEOService,
              private _meta: Meta,
              private _router: Router,
              private route: ActivatedRoute,
              private _title: Title) {
  }
  
  ngOnInit() {
    this.subscriptions.push(this.stakeholderService.getStakeholderAsObservable().subscribe(stakeholder => {
      this.stakeholder = stakeholder;
      if (this.stakeholder) {
        /* Metadata */
        const url = properties.domain + properties.baseLink + this._router.url;
        this.seoService.createLinkForCanonicalURL(url, false);
        this._meta.updateTag({content: url}, "property='og:url'");
        const description = "Methodology | " + this.stakeholder.name;
        const title = "Methodology | " + this.stakeholder.name;
        this._meta.updateTag({content: description}, "name='description'");
        this._meta.updateTag({content: description}, "property='og:description'");
        this._meta.updateTag({content: title}, "property='og:title'");
        this._title.setTitle(title);
      }
    }));
  }
  
  ngOnDestroy() {
    this.subscriptions.forEach(subscription => {
      if (subscription instanceof Subscription) {
        subscription.unsubscribe();
      }
    });
  }
}
